@@ -1,25 +1,33 @@
-//! # Some structs for Entity
+//! # About entity
+//! Entity in XECS is just an number ID.In XECS, it's just a 
+//! [NonZeroUsize](std::num::NonZeroUsize).
+//! The ID is allocated from 1 by world automatically. The ```id=0``` 
+//! represents a recycled ID without any other flags through ```Option<EntityId>```.
+//! # ID recycling
+//! When you call ```world.create_entity()```, an ID will be allocated automatically. 
+//! If you call ```world.remove_entity(id)```, this ID will be a pit. If the 
+//! next ```world.create_entity()``` is called, it will allocate this ID to fill 
+//! the pit.Thanks to sparse set, it's still fast to 
+//! iterate all components no matter how random of ID
 use std::num::NonZeroUsize;
-use crate::{World, Component};
-use std::cell::{Ref, RefMut};
+use crate::component::Component;
+use crate::world::World;
 
-/// An ID of entity ,starting at 1 ,can be re-used
+/// The type of ID of entity which starts from 1 and can be recycled automatically
 pub type EntityId = NonZeroUsize;
-/// A slice of EntityId
-pub type Entities = [EntityId];
 
-/// A useful struct for manipulating a entity
+/// A useful struct for building a entity
 #[derive(Debug)]
-pub struct EntityRef<'a>{
+pub struct EntityBuilder<'a>{
     world : &'a mut World,
-    id : EntityId
+    id : EntityId,
 }
 
-impl<'a> EntityRef<'a>{
-    pub(in crate) fn new(world : &'a mut World,entity_id : EntityId) -> EntityRef<'a>{
-        EntityRef{
+impl<'a> EntityBuilder<'a>{
+    pub(in crate) fn new(world : &'a mut World,entity_id : EntityId) -> Self{
+        EntityBuilder{
             world,
-            id: entity_id
+            id: entity_id,
         }
     }
 
@@ -28,31 +36,18 @@ impl<'a> EntityRef<'a>{
         self.id
     }
 
-    /// Attach a component to this entity
-    pub fn attach<T : Component>(self,component : T) -> EntityRef<'a>{
+    /// Attach a component to entity
+    pub fn attach<T : Component>(self,component : T) -> Self{
         self.world.attach_component(self.id,component);
         self
     }
 
-    /// Detach a component from this entity
-    pub fn detach<T : Component>(self) -> EntityRef<'a>{
+    /// Detach a component from entity
+    pub fn detach<T : Component>(self) -> Self{
         self.world.detach_component::<T>(self.id);//ignore the error
         self
     }
 
-    /// Get a reference of this entity's component
-    pub fn component_ref<T : Component>(&'a self) -> Ref<'a,T>{
-        // unwrap here
-        // because id must be a valid ID
-        self.world.entity_component_ref(self.id).unwrap()
-    }
-
-    /// Get a mutable reference of this entity's component
-    pub fn component_mut<T : Component>(&'a self) -> RefMut<'a,T>{
-        // unwrap here
-        // because id must be a valid ID
-        self.world.entity_component_mut(self.id).unwrap()
-    }
 }
 
 #[derive(Debug,Copy,Clone)]
@@ -95,7 +90,7 @@ impl EntityManager {
         }else{
             //full
             let id = self.entity_flags.len();
-            // safe here: because id cannot be zero
+            // safe here because id cannot be zero
             let id = unsafe { EntityId::new_unchecked(id) };
             self.entities.push(id);
             self.entity_flags.push(EntityFlag::Unavailable(self.entities.len() - 1));
@@ -104,19 +99,19 @@ impl EntityManager {
         }
     }
 
+    // remove entity id
+    // Do nothing if entity_id not exist
     pub(in crate) fn remove(&mut self,entity_id : EntityId) {
         let entity_id_ = entity_id.get();
         if let EntityFlag::Unavailable(index) = self.entity_flags[entity_id_] {
-            // unwrap safe : in this branch,we must has one entity at least
+            // unwrap safe: in this branch, we must have one entity at least
             let the_last_one_id = self.entities.last().unwrap();
             // move this entity to the end of entities
             self.entity_flags[the_last_one_id.get()] = EntityFlag::Unavailable(index);
             self.entities.swap_remove(index);
-            // keep this destroyed id be a chain
+            // keep these destroyed ids being a chain
             self.entity_flags[entity_id_] = self.entity_flags[0];
             self.entity_flags[0] = EntityFlag::Available(entity_id);
-        } else {
-            panic!("Entity is not existence");
         }
     }
 
@@ -140,8 +135,7 @@ impl EntityManager {
 
 #[cfg(test)]
 mod tests{
-    use crate::entity::EntityManager;
-    use crate::EntityId;
+    use crate::entity::{EntityId, EntityManager};
 
     #[test]
     fn manager_test() {
@@ -193,4 +187,4 @@ mod tests{
         println!("entities :{:?}",manager.entities.as_slice());
         println!();
     }
-}
\ No newline at end of file
+}
